@@ -35,6 +35,10 @@ class SendEventCommand(Command):
     :type delay: (optional) int
     :param description: A user-provided description of this command.
     :type description: (optional) str
+    :param screen_lock: If true, disable the Interaction Timer.
+    :type screen_lock: (optional) bool
+    :param sequencer: Specify the sequencer that should execute this command.
+    :type sequencer: (optional) str
     :param when: If false, the execution of the command is skipped. Defaults to true.
     :type when: (optional) bool
     :param arguments: An array of argument data to pass to Alexa.
@@ -47,6 +51,8 @@ class SendEventCommand(Command):
         'object_type': 'str',
         'delay': 'int',
         'description': 'str',
+        'screen_lock': 'bool',
+        'sequencer': 'str',
         'when': 'bool',
         'arguments': 'list[str]',
         'components': 'list[str]'
@@ -56,20 +62,26 @@ class SendEventCommand(Command):
         'object_type': 'type',
         'delay': 'delay',
         'description': 'description',
+        'screen_lock': 'screenLock',
+        'sequencer': 'sequencer',
         'when': 'when',
         'arguments': 'arguments',
         'components': 'components'
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, delay=None, description=None, when=None, arguments=None, components=None):
-        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[List[object]], Optional[List[object]]) -> None
+    def __init__(self, delay=None, description=None, screen_lock=None, sequencer=None, when=None, arguments=None, components=None):
+        # type: (Union[int, str, None], Optional[str], Optional[bool], Optional[str], Optional[bool], Optional[List[object]], Optional[List[object]]) -> None
         """The SendEvent command allows the APL author to generate and send an event to Alexa.
 
         :param delay: The delay in milliseconds before this command starts executing; must be non-negative. Defaults to 0.
         :type delay: (optional) int
         :param description: A user-provided description of this command.
         :type description: (optional) str
+        :param screen_lock: If true, disable the Interaction Timer.
+        :type screen_lock: (optional) bool
+        :param sequencer: Specify the sequencer that should execute this command.
+        :type sequencer: (optional) str
         :param when: If false, the execution of the command is skipped. Defaults to true.
         :type when: (optional) bool
         :param arguments: An array of argument data to pass to Alexa.
@@ -80,7 +92,7 @@ class SendEventCommand(Command):
         self.__discriminator_value = "SendEvent"  # type: str
 
         self.object_type = self.__discriminator_value
-        super(SendEventCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, when=when)
+        super(SendEventCommand, self).__init__(object_type=self.__discriminator_value, delay=delay, description=description, screen_lock=screen_lock, sequencer=sequencer, when=when)
         self.arguments = arguments
         self.components = components
 
